<?php
/**
 * @package     MPF
 * @subpackage  UI
 *
 * @copyright   Copyright (C) 2016 - 2018 Ossolution Team, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */
defined('_JEXEC') or die;


/**
 * Base class for a Joomla Administrator Controller. It handles add, edit, delete, publish, unpublish records....
 *
 * @package       MPF
 * @subpackage    UI
 * @since         2.0
 */
class RADUiGantry5 extends RADUiAbstract implements RADUiInterface
{
	/**
	 * Constructor
	 *
	 * @param array $classMaps
	 */
	public function __construct($classMaps = array())
	{
		if (empty($classMaps))
		{
			$classMaps = [
				'row-fluid'       => 'g-grid',
				'span1'           => 'g-block size-8-3',
				'span2'           => 'g-block size-16-7',
				'span3'           => 'g-block size-25',
				'span4'           => 'g-block size-33-3',
				'span5'           => 'g-block size-42',
				'span6'           => 'g-block size-50',
				'span7'           => 'g-block size-58',
				'span8'           => 'g-block size-66',
				'span9'           => 'g-block size-75',
				'span10'          => 'g-block size-83',
				'span11'          => 'g-block size-92',
				'span12'          => 'g-block size-100',
				'pull-left'       => 'float-left',
				'pull-right'      => 'float-right',
				'btn'             => 'button',
				'btn-mini'        => 'button',
				'btn-small'       => 'button',
				'btn-large'       => 'button',
				'btn-inverse'     => 'button',
				'visible-phone'   => 'visible-phone',
				'visible-tablet'  => 'visible-tablet',
				'visible-desktop' => 'visible-desktop',
				'hidden-phone'    => 'hidden-phone',
				'hidden-tablet'   => 'hidden-tablet',
				'hidden-desktop'  => 'hidden-desktop',
				'control-group'   => 'form-group form-row',
				'input-prepend'   => 'input-group-prepend',
				'input-append'    => 'input-group-append',
				'add-on'          => 'input-group-text',
				'img-polaroid'    => 'img-thumbnail',
				'control-label'   => 'g-block size-25 form-control-label',
				'controls'        => 'g-block size-75',
			];
		}

		$this->classMaps = $classMaps;
	}

	/**
	 * Get the mapping of a given class
	 *
	 * @param string $class The input class
	 *
	 * @return string The mapped class
	 */
	public function getClassMapping($class)
	{
		$mappedClass = parent::getClassMapping($class);

		if ($mappedClass !== null)
		{
			return $mappedClass;
		}

		// Handle icon class
		if (strpos($class, 'icon-') !== false)
		{
			$icon = substr($class, 5);

			return 'fa fa-' . $icon;
		}

		// If no class found, return original class
		return $class;
	}

	/**
	 * Method to render input with prepend add-on
	 *
	 * @param string $input
	 * @param string $addOn
	 *
	 * @return string
	 */
	public function getPrependAddon($input, $addOn)
	{
		$html   = [];
		$html[] = '<div class="input-group">';
		$html[] = '<div class="input-group-prepend">';
		$html[] = '<span class="input-group-text">' . $addOn . '</span>';
		$html[] = '</div>';
		$html[] = $input;
		$html[] = '</div>';

		return implode("\n", $html);
	}

	/**
	 * Method to render input with append add-on
	 *
	 * @param string $input
	 * @param string $addOn
	 *
	 * @return string
	 */
	public function getAppendAddon($input, $addOn)
	{
		$html   = [];
		$html[] = '<div class="input-group">';
		$html[] = $input;
		$html[] = '<div class="input-group-append">';
		$html[] = '<span class="input-group-text">' . $addOn . '</span>';
		$html[] = '</div>';
		$html[] = '</div>';

		return implode("\n", $html);
	}
}